@@ -30,10 +30,10 @@ class DB(_base.CVI):
         super().__init__()
 
         # CH-specific initialization
-        self.mu = np.zeros([0])     # dim
-        self.R = np.zeros([0, 0])   # n_clusters x dim
-        self.D = np.zeros([0, 0])   # n_clusters x n_clusters
-        self.S = []                 # dim
+        self._mu = np.zeros([0])     # dim
+        self._R = np.zeros([0, 0])   # n_clusters x dim
+        self._D = np.zeros([0, 0])   # n_clusters x n_clusters
+        self._S = []                 # dim
 
     @_base._add_docs(_base._setup_doc)
     def _setup(self, sample: np.ndarray):
@@ -45,7 +45,7 @@ class DB(_base.CVI):
         super()._setup(sample)
 
         # DB-specific setup
-        self.mu = sample
+        self._mu = sample
 
     @_base._add_docs(_base._param_inc_doc)
     def _param_inc(self, sample: np.ndarray, label: int):
@@ -54,94 +54,94 @@ class DB(_base.CVI):
         """
 
         # Get the internal label corresponding to the provided label
-        i_label = self.label_map.get_internal_label(label)
+        i_label = self._label_map.get_internal_label(label)
 
         # Increment the local number of samples count
-        n_samples_new = self.n_samples + 1
+        n_samples_new = self._n_samples + 1
 
         # Check if the module has been setup, then set the mu accordingly
-        if self.n_samples == 0:
+        if self._n_samples == 0:
             self._setup(sample)
         else:
-            self.mu = (
-                (1 - 1/n_samples_new) * self.mu
+            self._mu = (
+                (1 - 1/n_samples_new) * self._mu
                 + (1/n_samples_new) * sample
             )
 
         # IF NEW CLUSTER LABEL
         # Correct for python 0-indexing
-        if i_label > self.n_clusters - 1:
+        if i_label > self._n_clusters - 1:
             n_new = 1
             v_new = sample
             CP_new = 0.0
-            G_new = np.zeros(self.dim)
+            G_new = np.zeros(self._dim)
             S_new = 0.0
-            if self.n_clusters == 0:
+            if self._n_clusters == 0:
                 D_new = np.zeros((1, 1))
             else:
-                D_new = np.zeros((self.n_clusters + 1, self.n_clusters + 1))
-                D_new[0:self.n_clusters, 0:self.n_clusters] = self.D
-                d_column_new = np.zeros(self.n_clusters + 1)
-                for jx in range(self.n_clusters):
+                D_new = np.zeros((self._n_clusters + 1, self._n_clusters + 1))
+                D_new[0:self._n_clusters, 0:self._n_clusters] = self._D
+                d_column_new = np.zeros(self._n_clusters + 1)
+                for jx in range(self._n_clusters):
                     d_column_new[jx] = (
-                        np.sum((v_new - self.v[jx, :]) ** 2)
+                        np.sum((v_new - self._v[jx, :]) ** 2)
                     )
                 D_new[i_label, :] = d_column_new
                 D_new[:, i_label] = d_column_new
 
             # Update 1-D parameters with list appends
-            self.n_clusters += 1
-            self.n.append(n_new)
-            self.CP.append(CP_new)
-            self.S.append(S_new)
+            self._n_clusters += 1
+            self._n.append(n_new)
+            self._CP.append(CP_new)
+            self._S.append(S_new)
 
             # Update 2-D parameters with numpy vstacks
-            self.v = np.vstack([self.v, v_new])
-            self.G = np.vstack([self.G, G_new])
-            self.D = D_new
+            self._v = np.vstack([self._v, v_new])
+            self._G = np.vstack([self._G, G_new])
+            self._D = D_new
 
         # ELSE OLD CLUSTER LABEL
         else:
-            n_new = self.n[i_label] + 1
+            n_new = self._n[i_label] + 1
             v_new = (
-                (1 - 1 / n_new) * self.v[i_label, :]
+                (1 - 1 / n_new) * self._v[i_label, :]
                 + (1 / n_new) * sample
             )
-            delta_v = self.v[i_label, :] - v_new
+            delta_v = self._v[i_label, :] - v_new
             diff_x_v = sample - v_new
             CP_new = (
-                self.CP[i_label]
+                self._CP[i_label]
                 + np.inner(diff_x_v, diff_x_v)
-                + self.n[i_label] * np.inner(delta_v, delta_v)
-                + 2 * np.inner(delta_v, self.G[i_label, :])
+                + self._n[i_label] * np.inner(delta_v, delta_v)
+                + 2 * np.inner(delta_v, self._G[i_label, :])
             )
             G_new = (
-                self.G[i_label, :]
+                self._G[i_label, :]
                 + diff_x_v
-                + self.n[i_label] * delta_v
+                + self._n[i_label] * delta_v
             )
             S_new = CP_new / n_new
-            d_column_new = np.zeros(self.n_clusters)
-            for jx in range(self.n_clusters):
+            d_column_new = np.zeros(self._n_clusters)
+            for jx in range(self._n_clusters):
                 # Skip the current i_label index
                 if jx == i_label:
                     continue
                 d_column_new[jx] = (
-                    np.sum((v_new - self.v[jx, :]) ** 2)
+                    np.sum((v_new - self._v[jx, :]) ** 2)
                 )
 
             # Update parameters
-            self.n[i_label] = n_new
-            self.v[i_label, :] = v_new
-            self.CP[i_label] = CP_new
-            self.G[i_label, :] = G_new
-            self.S[i_label] = S_new
-            self.D[i_label, :] = d_column_new
-            # self.D[:, i_label] = np.tranpose(d_column_new)
-            self.D[:, i_label] = d_column_new
+            self._n[i_label] = n_new
+            self._v[i_label, :] = v_new
+            self._CP[i_label] = CP_new
+            self._G[i_label, :] = G_new
+            self._S[i_label] = S_new
+            self._D[i_label, :] = d_column_new
+            # self._D[:, i_label] = np.tranpose(d_column_new)
+            self._D[:, i_label] = d_column_new
 
         # Update the parameters that do not depend on label novelty
-        self.n_samples = n_samples_new
+        self._n_samples = n_samples_new
 
     @_base._add_docs(_base._param_batch_doc)
     def _param_batch(self, data: np.ndarray, labels: np.ndarray):
@@ -153,38 +153,38 @@ class DB(_base.CVI):
         super()._setup_batch(data)
 
         # Take the average across all samples, but cast to 1-D vector
-        self.mu = np.mean(data, axis=0)
+        self._mu = np.mean(data, axis=0)
         u = np.unique(labels)
-        self.n_clusters = u.size
-        # self.n = np.zeros(self.n_clusters, dtype=int)
-        self.n = [0 for _ in range(self.n_clusters)]
-        self.v = np.zeros((self.n_clusters, self.dim))
-        # self.CP = np.zeros(self.n_clusters)
-        self.CP = [0 for _ in range(self.n_clusters)]
-        self.G = np.zeros((self.n_clusters, self.dim))
-        self.D = np.zeros((self.n_clusters, self.n_clusters))
-        # self.S = np.zeros(self.n_clusters)
-        self.S = [0 for _ in range(self.n_clusters)]
+        self._n_clusters = u.size
+        # self._n = np.zeros(self._n_clusters, dtype=int)
+        self._n = [0 for _ in range(self._n_clusters)]
+        self._v = np.zeros((self._n_clusters, self._dim))
+        # self._CP = np.zeros(self._n_clusters)
+        self._CP = [0 for _ in range(self._n_clusters)]
+        self._G = np.zeros((self._n_clusters, self._dim))
+        self._D = np.zeros((self._n_clusters, self._n_clusters))
+        # self._S = np.zeros(self._n_clusters)
+        self._S = [0 for _ in range(self._n_clusters)]
 
-        for ix in range(self.n_clusters):
+        for ix in range(self._n_clusters):
             # subset_indices = lambda x: labels[x] == ix
             subset_indices = (
                 [x for x in range(len(labels)) if labels[x] == ix]
             )
             subset = data[subset_indices, :]
-            self.n[ix] = subset.shape[0]
-            self.v[ix, :] = np.mean(subset, axis=0)
-            diff_x_v = subset - self.v[ix, :] * np.ones((self.n[ix], 1))
-            self.CP[ix] = np.sum(diff_x_v ** 2)
-            self.S[ix] = self.CP[ix] / self.n[ix]
+            self._n[ix] = subset.shape[0]
+            self._v[ix, :] = np.mean(subset, axis=0)
+            diff_x_v = subset - self._v[ix, :] * np.ones((self._n[ix], 1))
+            self._CP[ix] = np.sum(diff_x_v ** 2)
+            self._S[ix] = self._CP[ix] / self._n[ix]
 
-        for ix in range(self.n_clusters - 1):
-            for jx in range(ix + 1, self.n_clusters):
-                self.D[ix, jx] = (
-                    np.sum((self.v[ix, :] - self.v[jx, :]) ** 2)
+        for ix in range(self._n_clusters - 1):
+            for jx in range(ix + 1, self._n_clusters):
+                self._D[ix, jx] = (
+                    np.sum((self._v[ix, :] - self._v[jx, :]) ** 2)
                 )
 
-        self.D = self.D + np.transpose(self.D)
+        self._D = self._D + np.transpose(self._D)
 
     @_base._add_docs(_base._evaluate_doc)
     def _evaluate(self):
@@ -192,16 +192,16 @@ class DB(_base.CVI):
         Criterion value evaluation method for the Davies-Bouldin (DB) CVI.
         """
 
-        if self.n_clusters > 1:
-            self.R = np.zeros((self.n_clusters, self.n_clusters))
-            for ix in range(self.n_clusters - 1):
-                for jx in range(ix + 1, self.n_clusters):
-                    self.R[jx, ix] = (
-                        (self.S[ix] + self.S[jx]) / self.D[jx, ix]
+        if self._n_clusters > 1:
+            self._R = np.zeros((self._n_clusters, self._n_clusters))
+            for ix in range(self._n_clusters - 1):
+                for jx in range(ix + 1, self._n_clusters):
+                    self._R[jx, ix] = (
+                        (self._S[ix] + self._S[jx]) / self._D[jx, ix]
                     )
-            self.R = self.R + np.transpose(self.R)
+            self._R = self._R + np.transpose(self._R)
             self.criterion_value = (
-                np.sum(np.max(self.R, axis=0)) / self.n_clusters
+                np.sum(np.max(self._R, axis=0)) / self._n_clusters
             )
         else:
             self.criterion_value = 0.0
