@@ -15,6 +15,8 @@ from .cSIL import cSIL
 from .DB import DB
 from .GD43 import GD43
 from .GD53 import GD53
+from .WB import WB
+from .XB import XB
 
 __all__ = [
     "LabelMap",
@@ -27,4 +29,6 @@ __all__ = [
     "DB",
     "GD43",
     "GD53",
+    "WB",
+    "XB",
 ]
